[ndata, text, alldata] = xlsread('TIP_2004_papers.xls');

for i=1:size(text,1)-2
    citations2004(i) = alldata{i+2,7};
    code2004(i) = length(alldata{i+2,8})>1;
    months2004(i) = 12*7 + (12-alldata{i+2,5}) + 2; % until Feb 2012
end

[ndata, text, alldata] = xlsread('TIP_2005_papers.xls');

for i=1:size(text,1)-2
    citations2005(i) = alldata{i+2,7};
    code2005(i) = length(alldata{i+2,8})>1;
    months2005(i) = 12*6 + (12-alldata{i+2,5}) + 2; % until Feb 2012
end

[ndata, text, alldata] = xlsread('TIP_2006_papers.xls');

for i=1:size(text,1)-2
    citations2006(i) = alldata{i+2,7};
    code2006(i) = length(alldata{i+2,8})>1;
    months2006(i) = 12*5 + (12-alldata{i+2,5}) + 2; % until Feb 2012
end

citations = [citations2004 citations2005 citations2006];
code = [3*code2004 3*code2005+1 3*code2006+2];
citationsfull = [citations2004 citations2005 citations2006];
codefull = [code2004 code2005 code2006];

fontsize = 14;
figure; 
plot(sort(citations2004,'descend'),'b-','Linewidth',2);
hold on;
plot(sort(citations2005,'descend'),'r--','Linewidth',2);
plot(sort(citations2006,'descend'),'g:','Linewidth',2);
legend('citations 2004','citations 2005','citations 2006');
set(gca,'XLim',[0 330],'YLim',[0 3300],'FontSize',fontsize);
xlabel('paper index','FontSize',fontsize); ylabel('number of citations','FontSize',fontsize);
set(gca,'YScale','log');
saveas(gcf,'citations.png');


figure;
h = boxplot(citations,code,'Labels',...
    {'not RR 04','not RR 05','not RR 06','RR 04','RR 05','RR 06'});
set(h(:,:),'linewidth',2);
ylabel('number of citations','FontSize',fontsize);
set(gca,'YScale','log');
set(gca,'YLim',[9 4000],'FontSize',fontsize);
text_h = findobj(gca, 'Type', 'text');
labels = {'RR 06','RR 05','RR 04','not RR 06','not RR 05','not RR 04'}; % inverse order
rotation = 45;
for cnt = 1:length(text_h)
    set(text_h(cnt), 'FontSize', fontsize,...
        'Rotation', rotation, ...
        'String', labels{cnt}, 'HorizontalAlignment', 'right','VerticalAlignment', 'top');
end
squeeze = 0.05;
left = 0.02;
right = 1;
bottom = squeeze;
top = 1-squeeze;
set(gca, 'OuterPosition', [left bottom right top])
saveas(gcf,'boxplot.png');

disp([length(codefull) length(code2004) length(code2005) length(code2006); ...
      sum(codefull==1) sum(code2004==1) sum(code2005==1) sum(code2006==1); ...
      100*sum(codefull==1)/length(codefull) 100*sum(code2004==1)/length(code2004) 100*sum(code2005==1)/length(code2005) 100*sum(code2006==1)/length(code2006); ...
      mean(citationsfull(codefull==0)) mean(citations2004(code2004==0)) mean(citations2005(code2005==0)) mean(citations2006(code2006==0)); ...
      mean(citationsfull(codefull==1)) mean(citations2004(code2004==1)) mean(citations2005(code2005==1)) mean(citations2006(code2006==1)); ...
      median(citationsfull(codefull==0)) median(citations2004(code2004==0)) median(citations2005(code2005==0)) median(citations2006(code2006==0)); ...
      median(citationsfull(codefull==1)) median(citations2004(code2004==1)) median(citations2005(code2005==1)) median(citations2006(code2006==1))]);
  
%   645.0000  134.0000  182.0000  329.0000
%    66.0000   12.0000   19.0000   35.0000
%    10.2326    8.9552   10.4396   10.6383
%    41.4249   61.7787   45.3252   30.8163
%   198.2727  438.3333  202.1053  113.8857
%    25.0000   37.0000   26.0000   20.5000
%    76.0000   87.5000  111.0000   67.0000

%% statistical tests: checking whether the median number of citations for
%  for papers with code online is significantly different from the other
%  papers, using the Mann-Whitney U-test
[p,h] = ranksum(citationsfull(codefull==0),citationsfull(codefull==1));
[p2004,h2004] = ranksum(citations2004(code2004==0),citations2004(code2004==1));
[p2005,h2005] = ranksum(citations2005(code2005==0),citations2005(code2005==1));
[p2006,h2006] = ranksum(citations2006(code2006==0),citations2006(code2006==1));

disp(['all : null hypothesis rejected ' num2str(h) ', p = ' num2str(p)]);
disp(['2004: null hypothesis rejected ' num2str(h2004) ', p = ' num2str(p2004)]);
disp(['2005: null hypothesis rejected ' num2str(h2005) ', p = ' num2str(p2005)]);
disp(['2006: null hypothesis rejected ' num2str(h2006) ', p = ' num2str(p2006)]);

% all : null hypothesis rejected 1, p = 6.6007e-011
% 2004: null hypothesis rejected 1, p = 0.048206
% 2005: null hypothesis rejected 1, p = 1.3677e-005
% 2006: null hypothesis rejected 1, p = 9.6782e-007

citations0 = sort(citationsfull(codefull==0),'descend');
citations1 = sort(citationsfull(codefull==1),'descend');

% remove top 10 cited papers and check whether conditions still hold
N = 10;
[p,h] = ranksum(citations0,citations1(N+1:end));

% check how many of the papers with code available with top citations can
% be removed before null hypothesis can not be rejected anymore
N = 1;
while (h==1)
    [p,h] = ranksum(citations0,citations1(N+1:end));
    N = N+1;
end
disp(['null hypothesis for all data not rejected when N>=' num2str(N-1)]);
% null hypothesis for all data not rejected when N>=27
